/*
 *  MIDI pattern processor
 *  by Shawn Hargreaves, 1995/96
 *
 *  Header file declaring machine-dependent routines for output to the 
 *  screen, reading the keyboard, accessing the MIDI interface, and
 *  timing things.
 */


#ifndef SYSDEP_H
#define SYSDEP_H


#ifdef DJGPP 

/****************************************************
 *  Definitions for djgpp (the MS-DOS port of gcc)  *
 ****************************************************/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <conio.h>
#include <time.h>

/* gcc wants ANSI-style function prototypes */
#define DEF(name, args)     name##args

int hw_init();
void hw_cleanup();

#define home()              gotoxy(1, 1)
#define del_to_eol()        clreol()
#define screen_out(x)       cputs(x)
#define screen_char(x)      putch(x)
#define clear_screen()      clrscr()
#define show_cursor()       _setcursortype(_NORMALCURSOR)
#define hide_cursor()       _setcursortype(_NOCURSOR)

#define keypressed()        kbhit()
#define readkey()           getch()

int midi_waiting();
unsigned char midi_in();
void midi_output(unsigned char byte);

/* the standard MS-DOS clock() only provides a resolution of 18.2 bps,
 * so it has to be replaced with the djgpp-specific uclock().
 */

#undef CLK_TCK
#define CLK_TCK     UCLOCKS_PER_SEC

#define clock()     uclock()


#else 

/********************************************************
 *  Definitions for the Atari ST, using Mark Williams C *
 ********************************************************/

#define MARK_WILLIAMS_C

#include <osbind.h>
#include <stdio.h>

/* Mark Williams C wants K&R-style function definitions */
#define DEF(name, args)     extern name()

/* no need to specially setup the Atari hardware */
#define hw_init()           0
#define hw_cleanup()

#define ESC                 27

#define home()              { Bconout(2, ESC); Bconout(2, 'H'); }
#define del_to_eol()        { Bconout(2, ESC); Bconout(2, 'K'); }
#define screen_out(x)       Cconws(x)
#define screen_char(x)      Bconout(2, x)
#define clear_screen()      { Bconout(2, ESC); Bconout(2, 'E'); }
#define show_cursor()       { Bconout(2, ESC); Bconout(2, 'e'); }
#define hide_cursor()       { Bconout(2, ESC); Bconout(2, 'f'); }

#define keypressed()        (Bconstat(2) != 0)
#define readkey()           (Bconin(2) & 0xFF)

#define midi_waiting()      (Bconstat(3) != 0)
#define midi_in()           Bconin(3)
#define midi_output(x)      Bconout(3, x)

/* for some reason Mark Williams C lacks headers for these... */
#define CLK_TCK 200
extern long clock();
extern char *malloc();
extern char *realloc();

#define srandom(x)  srand(x)
#define random()    rand()


#endif                      /* end of Atari definitions */


#endif  /* SYSDEP_H */
